@@ -9,6 +9,7 @@ typedef enum {
     BD_PART_ERROR_EXISTS,
     BD_PART_ERROR_INVAL,
     BD_PART_ERROR_FAIL,
+    BD_PART_ERROR_TECH_UNAVAIL,
 } BDPartError;
 
 typedef enum {
@@ -93,6 +94,19 @@ typedef struct BDPartDiskSpec {
 BDPartDiskSpec* bd_part_disk_spec_copy (BDPartDiskSpec *data);
 void bd_part_disk_spec_free (BDPartDiskSpec *data);
 
+typedef enum {
+    BD_PART_TECH_MBR = 0,
+    BD_PART_TECH_GPT,
+} BDPartTech;
+
+typedef enum {
+    BD_PART_TECH_MODE_CREATE_TABLE = 1 << 0,
+    BD_PART_TECH_MODE_MODIFY_TABLE = 1 << 1,
+    BD_PART_TECH_MODE_QUERY_TABLE  = 1 << 2,
+    BD_PART_TECH_MODE_MODIFY_PART  = 1 << 3,
+    BD_PART_TECH_MODE_QUERY_PART   = 1 << 4,
+} BDPartTechMode;
+
 /*
  * If using the plugin as a standalone library, the following functions should
  * be called to:
@@ -106,6 +120,8 @@ gboolean bd_part_check_deps ();
 gboolean bd_part_init ();
 void bd_part_close ();
 
+gboolean bd_part_is_tech_avail (BDPartTech tech, guint64 mode, GError **error);
+
 gboolean bd_part_create_table (const gchar *disk, BDPartTableType type, gboolean ignore_existing, GError **error);
 
 BDPartSpec* bd_part_get_part_spec (const gchar *disk, const gchar *part, GError **error);
